@@ -867,7 +867,7 @@ class BigML(object):
             'code': code,
             'error': error}
 
-    def _download(self, url, filename=None, wait_time=3, retries=10,
+    def _download(self, url, filename=None, wait_time=10, retries=10,
                   counter=0):
         """Retrieves a remote file.
 
@@ -882,10 +882,10 @@ class BigML(object):
 
         if code == HTTP_OK:
             try:
-                download_status = json.loads(response.content)
-                if download_status and isinstance(download_status, dict):
-                    if download_status['status']['code'] != 5:
-                        if counter < retries:
+                if counter < retries:
+                    download_status = json.loads(response.content)
+                    if download_status and isinstance(download_status, dict):
+                        if download_status['status']['code'] != 5:
                             time.sleep(get_exponential_wait(wait_time,
                                                             counter))
                             counter += 1
@@ -894,16 +894,27 @@ class BigML(object):
                                                   retries=retries,
                                                   counter=counter)
                         else:
-                            LOGGER.error("The maximum number of retries for "
-                                         " the download has been exceeded. "
-                                         "You can retry your command again in"
-                                         " a while.")
-                    elif counter < retries:
-                        return self._download(url, filename=filename,
-                                              wait_time=wait_time,
-                                              retries=retries, counter=retries)
+                            return self._download(url, filename=filename,
+                                                  wait_time=wait_time,
+                                                  retries=retries,
+                                                  counter=retries + 1)
+                elif counter == retries:
+                    LOGGER.error("The maximum number of retries "
+                                 " for the download has been "
+                                 " exceeded. You can retry your "
+                                 " command again in"
+                                 " a while.")
+                    return None
             except:
-                pass
+                # When download starts, response.content is no longer a JSON
+                # object and we must retry the download without testing for
+                # JSON content. This is achieved by using counter = retries + 1
+                # to single out this case.
+                if counter < retries:
+                    return self._download(url, filename=filename,
+                                          wait_time=wait_time,
+                                          retries=retries,
+                                          counter=retries + 1)
             if filename is None:
                 file_object = response.raw
             else:
@@ -1641,7 +1652,7 @@ class BigML(object):
         return errors_dict
 
 
-    def download_dataset(self, dataset, filename=None):
+    def download_dataset(self, dataset, filename=None, retries=10):
         """Donwloads dataset contents to a csv file or file object
 
         """
@@ -1650,7 +1661,9 @@ class BigML(object):
         dataset_id = get_dataset_id(dataset)
         if dataset_id:
             return self._download("%s%s%s" % (self.url, dataset_id,
-                                              DOWNLOAD_DIR), filename=filename)
+                                              DOWNLOAD_DIR),
+                                  filename=filename,
+                                  retries=retries)
         
 
     ##########################################################################
